package com.example.app1;

import android.graphics.Color;
import android.os.Bundle;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.AdapterView;
import android.widget.ArrayAdapter;
import android.widget.ListView;
import android.widget.TextView;

import androidx.fragment.app.Fragment;

public class findFragment extends Fragment {
    private ListView listView;
    private TextView contentText;
    private ListView playlistView;
    private int lastClickedPosition = -1; // 记录上次点击的位置
    @Override
    public View onCreateView(LayoutInflater inflater, ViewGroup container, Bundle savedInstanceState){
        View view = LayoutInflater.from(getActivity()).inflate(R.layout.fragment_find, container, false);
        init(view);

        // 默认显示热搜榜内容
        String[] defaultPlaylist = getPlaylistForItem(0);
        ArrayAdapter<String> defaultPlaylistAdapter = new ArrayAdapter<>(requireContext(),
                android.R.layout.simple_list_item_1, defaultPlaylist);
        playlistView.setAdapter(defaultPlaylistAdapter);
        return view;
    }

    private void init(View view) {
        // 初始化列表和内容显示区域
        listView = view.findViewById(R.id.list_view);
        contentText = view.findViewById(R.id.content_text);
        playlistView = view.findViewById(R.id.playlist_view);

        // 列表项
        final String[] listItems = {"热搜榜", "儿童热门榜", "影视热搜", "国风热搜", "外语热搜", "情歌热搜", "纯音乐热搜", "综艺热搜"};

        ArrayAdapter<String> adapter = new ArrayAdapter<>(requireContext(),
                android.R.layout.simple_list_item_1, listItems);
        listView.setAdapter(adapter);


        // 记录上次点击的位置
        lastClickedPosition = 0;

        // 点击列表项更新内容显示区域的内容和右侧的歌单内容
        listView.setOnItemClickListener(new AdapterView.OnItemClickListener() {
            @Override
            public void onItemClick(AdapterView<?> parent, View view, int position, long id) {
                // 恢复上一个点击项的背景颜色
                if (lastClickedPosition != -1) {
                    View lastClickedView = parent.getChildAt(lastClickedPosition);
                    lastClickedView.setBackgroundColor(Color.TRANSPARENT); // 恢复默认背景色
                }

                // 获取点击的视图
                View clickedView = parent.getChildAt(position);
                // 修改背景颜色为粉色
                clickedView.setBackgroundColor(Color.parseColor("#FBBCDC")); // 粉色
                // 更新上次点击的位置
                lastClickedPosition = position;

                // 更新右侧歌单内容
                String[] playlist = getPlaylistForItem(position);
                ArrayAdapter<String> playlistAdapter = new ArrayAdapter<>(requireContext(),
                        android.R.layout.simple_list_item_1, playlist);
                playlistView.setAdapter(playlistAdapter);
            }
        });
    }

    private String[] getPlaylistForItem(int position) {
        // 根据位置返回相应的歌单内容
        switch (position) {
            case 0:
                return new String[]{"无名的人", "落", "如果可以","若月亮没有来","梨花香","下辈子早点相遇","如果爱忘了","离别开出花","dadada","别爱太满别睡太晚","我把故事酿成酒","梦驼铃","安河桥","你"};
            case 1:
                return new String[]{"贝乐虎儿歌", "宝宝巴士", "睡前故事晚安宝贝","寓言故事","黑猫警长救援队","兔小贝睡前故事","宝宝巴士儿歌","迷你特工队","咕力律动儿歌","冰雪奇缘","海绵宝宝","海底小纵队儿歌","一千零一夜睡前故事","熊出没"};
            case 2:
                return new String[]{"与凤行", "花间令", "热辣滚烫","繁花","烈焰","追风者","别对我动心","谢谢你温暖我","南来北往","在暴雪时分","小日子","大理寺少卿游","祈今朝","周处除三害"};
            case 3:
                return new String[]{"霜雪千年", "青花瓷", "红昭愿","上春山","卜卦","天下","桃花诺","画心","红尘客栈","年轮","牵丝戏","若梦","赤伶","武家坡"};
            case 4:
                return new String[]{"fate", "magnetic", "call of silence","see you again","back seat","swag","love story","repeat","hey oh","sheesh","wake","any song","heaven","doar cu tine"};
            case 5:
                return new String[]{"紫荆花盛开", "不如见一面", "悬溺","你冷落我我就放弃你","谁","犯错","你把爱情给了谁","负我不负她","霜雪千年","沉溺","打歌妹","浴室","爱情转移","把回忆拼好给你"};
            case 6:
                return new String[]{"daydream", "碧苍战歌", "瞬间的永恒","daylight","windy hill","夜空的寂静","神明无止","误入迷失森林","秋的思念","诀别书","水墨兰亭","城南花已开","summer","引忘川"};
            case 7:
                return new String[]{"就是爱你", "谈恋爱", "慢冷","流沙","暖暖","小宇","桃花运","挚友","问","一眼","怎样","想你时风起","我的美丽","分飞"};
            default:
                return new String[]{};
        }
    }
}
