package com.example.app1;

import android.content.Context;
import android.database.Cursor;
import android.database.sqlite.SQLiteDatabase;
import android.database.sqlite.SQLiteOpenHelper;

import java.util.ArrayList;
import java.util.HashSet;
import java.util.List;

public class DBHelper extends SQLiteOpenHelper {

    // 数据库名称和版本号
    private static final String DATABASE_NAME = "user_db";
    private static final int DATABASE_VERSION = 1;

    // 表名和列名
    private static final String TABLE_USERS = "users";
    private static final String COLUMN_ID = "id";
    private static final String COLUMN_USERNAME = "username";
    private static final String COLUMN_PASSWORD = "password";

    // 创建用户表的SQL语句
    private static final String SQL_CREATE_TABLE_USERS =
            "CREATE TABLE " + TABLE_USERS + " (" +
                    COLUMN_ID + " INTEGER PRIMARY KEY AUTOINCREMENT," +
                    COLUMN_USERNAME + " TEXT," +
                    COLUMN_PASSWORD + " TEXT)";

    // 构造方法
    public DBHelper(Context context) {
        super(context, DATABASE_NAME, null, DATABASE_VERSION);
    }

    @Override
    public void onCreate(SQLiteDatabase db) {
        // 创建用户表
        db.execSQL(SQL_CREATE_TABLE_USERS);
    }

    @Override
    public void onUpgrade(SQLiteDatabase db, int oldVersion, int newVersion) {
        // 数据库升级时执行的操作（暂不处理）
    }

    public List<User> getAllUsers() {
        List<User> userList = new ArrayList<>();
        String selectQuery = "SELECT  * FROM " + TABLE_USERS;

        SQLiteDatabase db = this.getWritableDatabase();
        Cursor cursor = db.rawQuery(selectQuery, null);

        // 用于记录已经显示的用户名和密码
        HashSet<String> displayedUserData = new HashSet<>();

        // 遍历游标，并将数据添加到用户列表中
        if (cursor.moveToFirst()) {
            do {
                // 获取当前游标位置的用户名和密码
                String username = cursor.getString(cursor.getColumnIndex(COLUMN_USERNAME));
                String password = cursor.getString(cursor.getColumnIndex(COLUMN_PASSWORD));

                // 生成用户数据字符串，用于检查是否重复
                String userDataString = username + "_" + password;

                // 如果该用户数据未在之前显示过，则将用户添加到列表中
                if (!displayedUserData.contains(userDataString)) {
                    User user = new User();
                    user.setId(cursor.getInt(cursor.getColumnIndex(COLUMN_ID)));
                    user.setUsername(username);
                    user.setPassword(password);
                    userList.add(user);

                    // 将当前用户数据标记为已显示
                    displayedUserData.add(userDataString);
                }
            } while (cursor.moveToNext());
        }

        // 关闭游标和数据库连接
        cursor.close();
        db.close();

        return userList;
    }

}
