package com.example.app1;

import android.annotation.SuppressLint;
import android.app.NotificationChannel;
import android.app.NotificationManager;
import android.content.DialogInterface;
import android.content.Intent;
import android.content.SharedPreferences;
import android.os.Build;
import android.os.Bundle;
import android.util.Log;
import android.view.View;
import android.widget.Button;
import android.widget.EditText;
import android.widget.Toast;

import androidx.activity.EdgeToEdge;
import androidx.appcompat.app.AlertDialog;
import androidx.appcompat.app.AppCompatActivity;
import androidx.core.graphics.Insets;
import androidx.core.view.ViewCompat;
import androidx.core.view.WindowInsetsCompat;

import java.util.List;


public class MainActivity2 extends AppCompatActivity {

    private EditText username;
    private EditText password;
    private Button login,lookButton;
    private Button startServiceButton;
    private boolean isServiceRunning = false;
    private DBHelper dbHelper; // 数据库助手类

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.user_login);
        //初始化视图
        username = findViewById(R.id.username);
        password = findViewById(R.id.password);
        login = findViewById(R.id.login);
        startServiceButton = findViewById(R.id.btnStartService);// 开始时间推送服务按钮
        lookButton = findViewById(R.id.look); // 查看用户数据按钮
        // 创建通知渠道
        if (Build.VERSION.SDK_INT >= Build.VERSION_CODES.O) {
            NotificationChannel channel = new NotificationChannel("channel_id", "Channel Name", NotificationManager.IMPORTANCE_DEFAULT);
            NotificationManager notificationManager = getSystemService(NotificationManager.class);
            notificationManager.createNotificationChannel(channel);
        }

        // 初始化数据库助手类
        dbHelper = new DBHelper(MainActivity2.this);

        // 启动服务按钮点击事件
        startServiceButton.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                if (!isServiceRunning) {
                    startMyService();
                    isServiceRunning = true;
                }
            }
        });

        // 登录按钮点击事件
        login.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                String strUsername = username.getText().toString().trim();
                String strPassword = password.getText().toString().trim();

                // 获取所有用户数据
                List<User> userList = dbHelper.getAllUsers();

                // 检查是否有用户数据
                if (!userList.isEmpty()) {
                    // 遍历用户数据列表
                    for (User user : userList) {
                        String savedUsername = user.getUsername();
                        String savedPassword = user.getPassword();

                        // 检查用户名和密码是否匹配
                        if (strUsername.equals(savedUsername) && strPassword.equals(savedPassword)) {
                            Toast.makeText(MainActivity2.this, "恭喜，登录成功！", Toast.LENGTH_SHORT).show();
                            Intent intent1 = new Intent(MainActivity2.this, IndexActivity.class);
                            startActivity(intent1);
                            return; // 如果匹配成功，则直接返回，不再继续循环
                        }
                    }
                    // 如果循环结束仍未匹配成功，则提示用户名或密码错误
                    Toast.makeText(MainActivity2.this, "用户名或密码错误！", Toast.LENGTH_SHORT).show();
                } else {
                    // 如果用户数据列表为空，则提示用户名或密码错误
                    Toast.makeText(MainActivity2.this, "用户名或密码错误！", Toast.LENGTH_SHORT).show();
                }
            }
        });

        // 查看用户数据按钮点击事件
        lookButton.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                // 获取所有用户数据
                List<User> userList = dbHelper.getAllUsers();

                // 创建对话框来显示用户数据
                AlertDialog.Builder builder = new AlertDialog.Builder(MainActivity2.this);
                builder.setTitle("用户数据");

                // 构建用户数据字符串
                StringBuilder userData = new StringBuilder();
                for (User user : userList) {
                    userData.append("ID: ").append(user.getId()).append(", ")
                            .append("用户名: ").append(user.getUsername()).append(", ")
                            .append("密码: ").append(user.getPassword()).append("\n");
                }

                // 将用户数据设置到对话框中
                builder.setMessage(userData.toString());

                // 设置对话框的按钮
                builder.setPositiveButton("确定", new DialogInterface.OnClickListener() {
                    public void onClick(DialogInterface dialog, int id) {
                        // 点击确定按钮的逻辑
                        dialog.dismiss(); // 关闭对话框
                    }
                });

                // 创建并显示对话框
                AlertDialog dialog = builder.create();
                dialog.show();
            }
        });
    }

    //开始时间推送服务
    private void startMyService() {
        Intent serviceIntent = new Intent(this, MyService.class);
        startService(serviceIntent);
    }

    //点击注册按钮时，跳转到注册界面
    public void zhuce(View view) {
        Intent intent2 = new Intent(MainActivity2.this, MainActivity3.class);
        startActivity(intent2);
    }
}

