package com.example.time;

import android.os.Bundle;
import android.widget.TextView;
import java.text.SimpleDateFormat;

import androidx.appcompat.app.AppCompatActivity;

import java.util.Date;
import java.util.Locale;

public class MainActivity extends AppCompatActivity {

    private TextView clockTextView;
    private TextView dateTextView;

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_main);

        // 绑定 TextView
        clockTextView = findViewById(R.id.clockTextView);
        dateTextView = findViewById(R.id.dateTextView);

        // 启动时钟更新线程
        updateClock();
    }

    private void updateClock() {
        // 创建线程
        Thread thread = new Thread() {
            @Override
            public void run() {
                try {
                    while (!isInterrupted()) {
                        // 在UI线程中更新时钟和日期
                        runOnUiThread(new Runnable() {
                            @Override
                            public void run() {
                                // 获取当前时间
                                long currentTimeMillis = System.currentTimeMillis();
                                // 格式化时间
                                SimpleDateFormat timeFormat = new SimpleDateFormat("HH:mm:ss", Locale.getDefault());
                                SimpleDateFormat dateFormat = new SimpleDateFormat("yyyy年 MM月 dd日 ", Locale.getDefault());
                                String currentTime = timeFormat.format(new Date(currentTimeMillis));
                                String currentDate = dateFormat.format(new Date(currentTimeMillis));
                                // 更新TextView
                                clockTextView.setText(currentTime);
                                dateTextView.setText(currentDate);
                            }
                        });
                        // 等待一秒钟
                        Thread.sleep(1000);
                    }
                } catch (InterruptedException e) {
                    e.printStackTrace();
                }
            }
        };
        // 启动线程
        thread.start();
    }
}
